utils::globalVariables(c(
  "stats", "binomial", "coef", "confint.default", "glm",
  "pnorm", "qnorm", "quantile", "update", "vcov", "askYesNo", "grep",
  "str2lang", "model.frame", "is", "plnorm"
))
